BridgefyDelegate mixin

Definition of the functions required to handle events occurred in the Bridgefy SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bridgefyDidConnect({required String userID}) → void
This function is called to notify a new connection.
bridgefyDidDestroySession() → void
The current session was destroyed
bridgefyDidDisconnect({required String userID}) → void
This function is called to notify a disconnection.
bridgefyDidEstablishSecureConnection({required String userID}) → void
This function is called to notify when an on-demand secure connection was established.
bridgefyDidFailSendingMessage({required String messageID, BridgefyError? error}) → void
This function is called when the message could not be sent
bridgefyDidFailToDestroySession() → void
An error occurred while destroying the current session
bridgefyDidFailToEstablishSecureConnection({required String userID, required BridgefyError error}) → void
This function is called to notify when an on-demand secure connection could not be established.
bridgefyDidFailToStart({required BridgefyError error}) → void
This function is called when an error occurred while starting the BridgefySDK.
bridgefyDidFailToStop({required BridgefyError error}) → void
This function is called when an error occurred while stopping the BridgefySDK.
bridgefyDidReceiveData({required Uint8List data, required String messageId, required BridgefyTransmissionMode transmissionMode}) → void
This function is called when a new message is received
bridgefyDidSendDataProgress({required String messageID, required int position, required int of}) → void
Called when there is progress while transmitting data. Only available on Android.
bridgefyDidSendMessage({required String messageID}) → void
This function is called when you confirm the sending of the message
bridgefyDidStart({required String currentUserID}) → void
This function is called when the BridgefySDK has been started.
bridgefyDidStop() → void
This function is called when the BridgefySDK has been stopped.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited